/*
 * Copyright 2010 Proofpoint, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.airlift.discovery.client;

import com.google.common.base.Function;
import com.google.common.util.concurrent.CheckedFuture;
import com.google.common.util.concurrent.Futures;
import com.google.common.util.concurrent.ListenableFuture;

import java.util.concurrent.CancellationException;
import java.util.concurrent.ExecutionException;

class DiscoveryFutures
{
    static <T> CheckedFuture<T, DiscoveryException> toDiscoveryFuture(final String name, ListenableFuture<T> future)
    {
        return Futures.makeChecked(future, new Function<Exception, DiscoveryException>()
        {
            @Override
            public DiscoveryException apply(Exception e)
            {
                if (e instanceof InterruptedException) {
                    Thread.currentThread().interrupt();
                    return new DiscoveryException(name + " was interrupted");
                }
                if (e instanceof CancellationException) {
                    return new DiscoveryException(name + " was canceled");
                }

                Throwable cause = e;
                if (e instanceof ExecutionException) {
                    if (e.getCause() != null) {
                        cause = e.getCause();
                    }
                }

                if (cause instanceof DiscoveryException) {
                    return (DiscoveryException) cause;
                }

                return new DiscoveryException(name + " failed", cause);
            }
        });
    }

}
